@@ -1,9 +1,12 @@
-import numpy as np
 import collections
+
+import numpy as np
 import sortedcontainers
-from .pauli import Pauli, PauliExpectation, PauliString
+from itertools import repeat
 from .algebra import Algebra
-from .circuit import Gate, Circuit
+from .circuit import Circuit, Gate
+from .pauli import Pauli, PauliExpectation, PauliString
+
 
 class Backend(object):
 
@@ -260,6 +263,36 @@ class Backend(object):
             nmeasurement=nmeasurement,
             )
 
+    def run_measurements(
+        self,
+        circuits,
+        nmeasurement=None
+    ):
+
+        """ Run a sequence of circuits using measurement-based computing. 
+
+        Returns a sequence of ProbabilityHistogram objects.
+
+        As the circuits could be very different, statevector input or min_qubit/nqubit
+        are not supported.  The default behaviour is to simply run the circuits in
+        sequence, but on some hardware backends a speed advantage can be gained by
+        batching circuits into jobs.
+
+        Args:
+            circuits (Sequence[Circuit]): the circuits to run
+            nmeasurement (int or Sequence[int] or None): number of measurements to sample. If
+                None, infinite sampling is assumed and the probabilities are
+                directly returned in ProbabilityHistogram format (default - `None`)
+                If an int, that number of measurements will be used for all circuits.  If a sequence,
+                run_measurements returns the shortest of len(circuits) and len(nmeasurement).
+
+        Returns:
+            list[ProbabilityHistogram]: list of histograms of projective measurements taken while running
+            the circuits
+        """
+        nmeasurements = repeat(nmeasurement) if (isinstance(nmeasurement, int) or (nmeasurement is None)) else nmeasurement
+        return [self.run_measurement(circuit=circuit, nmeasurement=nmeasurement) for (circuit, nmeasurement) in zip(circuits, nmeasurements)]
+
     def run_pauli_expectation(
         self,
         circuit,
